/*
  MySQL SQL query script for Tournament database
  Designed for MariaDB RDBMS

  NOTE: included data values are mostly fictional and computer-generated, and thus do not contain any real personal data

  Author:
    Pekka Helenius <fincer89 [at] hotmail [dot] com>
    2019
*/

-- -----------------------------------------------------
-- Assumes that database 'tournament_db' exists
USE tournament_db;

-- -----------------------------------------------------
-- Insert data for table COUNTRY
-- -----------------------------------------------------

INSERT INTO COUNTRY (id, name) VALUES
  ('FI', 'Finland'),
  ('NO', 'Norway'),
  ('US', 'United States'),
  ('DE', 'Germany'),
  ('RU', 'Russia'),
  ('EE', 'Estonia'),
  ('JP', 'Japan'),
  ('AR', 'Argentina'),
  ('IS', 'Iceland'),
  ('AT', 'Austria'),
  ('BR', 'Brazil'),
  ('DK', 'Denmark'),
  ('SE', 'Sweden'),
  ('IR', 'Iran'),
  ('MT', 'Malta'),
  ('PR', 'Puerto Rico'),
  ('SI', 'Slovenia'),
  ('VN', 'Vietnam')
;

-- -----------------------------------------------------
-- Insert data for table CITY
-- -----------------------------------------------------

INSERT INTO CITY (postalcode, country_id, name) VALUES
  ('20540',     'FI', 'Halinen'),
  ('00750',     'FI', 'Helsinki'),
  ('00880',     'FI', 'Helsinki'),
  ('00510',     'FI', 'Helsinki'),
  ('20780',     'FI', 'Kaarina'),
  ('90404',     'US', 'Santa Monica'),
  ('80339',     'DE', 'München'),
  ('397561',    'RU', 'Ни́жний Но́вгород'),
  ('530-0013',  'JP', '茶屋町駅'),
  ('5409',      'AR', 'San Roque'),
  ('7562',      'AT', 'Eltendorf'),
  ('28750-000', 'BR', 'Trajano De Morais'),
  ('7830',      'DK', 'Vinderup'),
  ('147 41',    'SE', 'Tumba'),
  ('14735',     'US', 'Fillmore'),
  ('60185',     'US', 'West Chicago'),
  ('3747',      'US', 'Santiago Del Estero'),
  ('972 31',    'SE', 'Luleå'),
  ('90045',     'US', 'Los Angeles'),
  ('112 20',    'SE', 'Stockholm'),
  ('1060',      'AT', 'Vienna'),
  ('50679',     'DE', 'Cologne'),
  ('06100',     'FI', 'Porvoo'),
  ('92054',     'US', 'San Diego County'),
  ('92374',     'US', 'San Bernardino County'),
  ('5020',      'AT', 'Salzburg'),
  ('454085',    'RU', 'Челя́бинск'),
  ('456780',    'RU', 'Челя́бинск'),
  ('454017',    'RU', 'Челя́бинск'),
  ('6400',      'DK', 'Sønderborg'),
  ('371-0022',  'JP', '前橋市'),
  ('15257',     'SE', 'Fornhöjden'),
  ('431-1209',  'JP', '浜松市'),
  ('431-1208',  'JP', '浜松市'),
  ('432-8058',  'JP', '浜松市'),
  ('5710',      'AT', 'Salzburg'),
  ('30285-110', 'BR', 'Vila Alto Vera Cruz'),
  ('8270',      'DK', 'Højbjerg'),
  ('433100',    'RU', 'улица Маяковского'),
  ('55118',     'US', 'West Saint Paul'),
  ('40212',     'US', 'Louisville'),
  ('47147',     'IR', 'بخش مرکزی'),
  ('983-0013',  'JP', '宮城野区'),
  ('142702',    'RU', 'микрорайон'),
  ('056',       'VN', 'Hoàng Hoa Thám'),
  ('413 22',    'SE', 'Guldheden'),
  ('90768',     'DE', 'Eschenau'),
  ('09185-220', 'BR', 'Vila Alzira'),
  ('90009',     'FI', 'Oulu'),
  ('74130',     'FI', 'Iisalmi'),
  ('474-1161',  'JP', '松戸市'),
  ('167-1197',  'JP', '盛岡市'),
  ('203-1112',  'JP', '山田町'),
  ('85034',     'US', 'Phoenix'),
  ('115563',    'RU', 'райо́н Оре́хово-Бори́сово Ю́жное'),
  ('109429',    'RU', 'улица Капотня'),
  ('140050',    'RU', 'Мала́ховка'),
  ('412 62',    'SE', 'Göteborg'),
  ('951 74',    'SE', 'Luleå'),
  ('12157',     'DE', 'Berlin'),
  ('13472-370', 'BR', 'Americana'),
  ('06725-005', 'BR', 'Cotia'),
  ('02184',     'US', 'Norfolk County'),
  ('8300LSB',   'AR', 'Neuquén')
;

-- -----------------------------------------------------
-- Insert data for table TEAM
-- -----------------------------------------------------

INSERT INTO TEAM (id, name, email, phone, postalcode, street, housenumber, IBAN, SWIFT_bank, SWIFT_number) VALUES
  ('J001', 'Rollihaukat', 'rollihaukat@gmail.com', '+358554319543', '20540', 'Paavinkatu', '4C', 'FI4870716142809720', NULL, NULL),
  ('J002', 'バトルスピリッツ', 'battlespirits@anet.ne.jp', '+81387453711', '983-0013', '県道仙台塩釜線', NULL, NULL, 'AXIPJPJTCRI', '9188091866'),
  ('J003', 'FreeRiders', 'freeriders@yahoo.com', '270-209-4072', '40212', 'North Shawnee Terrace', '122', NULL, 'BBFXUS6SXXX', '08126017296'),
  ('J004', 'Red Hats', 'redhats@mail.ru', '+7(8442)310713', '142702', 'Советская улица', '50E 4', NULL, 'ALTKRUMMXXX', '0386518487'),
  ('J005', 'Dất Xanh', 'datxahn@gmail.com', '+94(844)37715142', '056', 'Chợ Đầm', NULL, NULL, 'BFTVVNVX038', '990370669360'),
  ('J006', 'Vita Frost Bringararna', 'vitafrost@altavista.se', '+4603042602798', '413 22', 'Doktor Saléns gata', '26B 2', 'SE0743592495897587599293', NULL, NULL),
  ('J007', 'Top Rollenspieler', 'toprollenspieler@outlook.com', '+4909471836895', '90768', 'Kannenbergstraße', '46', 'DE62254595460069188490', NULL, NULL),
  ('J008', 'Comedores de Caveira', 'comcaveira@hotmail.com', '+55(51)30337837', '09185-220', 'Rua Otávio Marques', '4', 'BR6471353461367518996277792HU', NULL, NULL),
  ('J009', 'برادران نبرد پارسی', 'battlebrothers@protonmail.com', '(+9821)8058594', '47147', 'معلم, کمال محله', NULL, 'IR106484270506068042332457', NULL, NULL)
;

-- -----------------------------------------------------
-- Insert data for table PLAYER
-- -----------------------------------------------------

INSERT INTO PLAYER (id, team_id, firstname, lastname, email, phone, postalcode, street, housenumber) VALUES
  ('P001', 'J001', 'Anita', 'Tilhonen', 'anita.tilhonen@gmail.com', '+3584634151416', '20780', 'Hoviherrankatu', '2A 5'),
  ('P002', 'J001', 'Johanna', 'Nikulainen', 'jniku@gmail.com', '+3580418003929', '90009', 'Jalonkatu', '38'),
  ('P003', 'J002', 'Sei', 'Kuwana', 'ameonna.sei@excite.co.jp', '+81392789972', '474-1161', 'マツドシ', NULL),
  ('P004', 'J002', 'Minan', 'Ikegami', 'amaterasu87@lolipop.jp', NULL, '167-1197', 'モリオカシ', NULL),
  ('P005', 'J002', 'Yuichi', 'Mitsuishi', 'hitodama.yuc@conoha.jp', '+81143557146', '203-1112', 'シモヘイグンヤマダマチ', NULL),
  ('P006', 'J003', 'Mark', 'Baylor', 'hydra884@gmail.com', '480-207-6961', '85034', 'Dye Street', '2122'),
  ('P007', 'J003', 'Lisa', 'Ford', 'cartoonqueen@gmail.com', '480-254-7889', '85034', 'East Avenue', '1719'),
  ('P008', 'J004', 'Esther', 'Bazarova', 'tordlin@imail.ru', '+7(3452)778193', '115563', 'Детский сад №', '36 к6'),
  ('P009', 'J004', 'Lolita', 'Pirogova', 'bremalin@gmail.com', '+7(8142)274283', '109429', 'Детская музыкальная школа имени Н.Н. Калинина', '3'),
  ('P010', 'J004', 'Myron', 'Ponomarev', 'stormknight@au.ru', '+7(3452)178318', '140050', 'Люберецкий Дом ребёнка', NULL),
  ('P011', 'J004', 'Nicanor', 'Tokaryev', 'zialana@sendmail.ru', '+7(8112)133139', '140050', 'улица Суворова', NULL),
  ('P012', 'J005', 'Lạc', 'Trọng Phu', 'phenomicalevent@gmail.com', NULL, NULL, NULL, NULL),
  ('P013', 'J006', 'Niki', 'Lindqvist', 'flyswatter@telia.se', '+4601747700680', '412 62', 'Eriksbo Västergärde', '38'),
  ('P014', 'J007', 'Melanie', 'Schweitzer', 'hardlewain@gmx.com', '+4905872860059', NULL, NULL, NULL),
  ('P015', 'J007', 'Johanna', 'Wechsler', 'scholtz@web.de', '+4909231339578', '12157', 'Genslerstraße', '7A 8'),
  ('P016', 'J008', 'Larissa', 'Alves Ferreira', 'larissa.ferreira@gmail.com', '+55(61)32004141', '06725-005', 'Rua Alexandrina', '1126'),
  ('P017', 'J009', 'علوی', 'فرود', 'bloodlust@gmail.com', NULL, NULL, NULL, NULL),
  ('P018', 'J009', 'جوادی', 'کسرا', 'swordofheat@yahoo.com', NULL, NULL, NULL, NULL),
  ('P019', 'J006', 'Sebastian', 'Engström', 'sebastian.engstrom@outlook.com', '+4605207348333', '951 74', 'Knektvägen', '89'),
  ('P020', 'J005', 'Hàn', 'Hữu Nghi', 'uberiorr@gmail.com', NULL, NULL, NULL, NULL),
  ('P021', 'J005', 'Lê', 'Đình Hưng', 'soldier_of_win@gmail.com', NULL, NULL, NULL, NULL),
  ('P022', 'J008', 'Beatrice', 'Cavalcanti Pinto', 'boitatacrawler@gmail.com', '+55(11)49453672', '13472-370', 'Rua São Bento', '1570'),
  ('P023', 'J001', 'Senja', 'Virolainen', 'moaderspin@outlook.com', '+3580507399907', '74130', 'Pihlajaharjuntie', '2')
;

-- -----------------------------------------------------
-- Insert data for table ORGANIZER_ORG
-- -----------------------------------------------------

INSERT INTO ORGANIZER_ORG (id, name, email, phone, postalcode, street, housenumber) VALUES
  ('O001', 'Peliturnarit', 'firstname.lastname@peliturnarit.fi', '+3585043239534', '00750', 'Keskitie', '20'),
  ('O002', 'Global Board Game Association', 'firstname.lastname@globalbgass.com', '310-315-5982', '90404', '18th Court', '4'),
  ('O003', 'Erste Dungeonreihenfolge', 'vorname.nachname@erdunfolge.de', '+4907356748808', '80339', 'Hartwaldstraße', '5'),
  ('O004', 'северные медведи', 'imya.familiya@sevnesti.ru', '+7(8552)465742', '397561', 'городское поселение Пристень', '21'),
  ('O005', 'ロイヤルゲーマー', 'namae.myoji@roiyarugema.ja', '+81398962866', '530-0013', 'Kurashiki', '中庄'),
  ('O006', 'Organización de mejora de nivel', 'nombre.apellido@orgnivel.ar', '+541146604728', '5409', 'Calle Ínter de Milán', '2A'),
  ('O007', 'Europäische Grenze Spielen', 'vorname.nachname@eurspielen.at', '+4306762298756', '7562', 'Zipfgasse', '2'),
  ('O008', 'Associação Sul-Americana de Jogos de Tabuleiro', 'primeiro.ultimo@tabuleiro.br', '+55(28)90807333', '28750-000', 'Rua Armindo Sena', '1'),
  ('O009', 'Ægte spillere', 'fornavn.efternavn@agtespillere.dk', '+4581563317', '7830', 'Toften', '11'),
  ('O010', 'Förlorade Vikingarna', 'fornamn.efternamn@forloradeviking.se', '+4609112343501', '147 41', 'Grödingevägen', '7C'),
  ('O011', 'North American Challenger Teams', 'firstname.lastname@americanchallenger.com', '218-212-8737', '14735', 'Lowel Road', '1')
;

-- -----------------------------------------------------
-- Insert data for table ORG_EMPLOYEE
-- -----------------------------------------------------

INSERT INTO ORG_EMPLOYEE (id, organizer_org_id, firstname, lastname, email, phone, postalcode, street, housenumber) VALUES
  ('T001', 'O001', 'Heikki', 'Isomaa', 'heikki.isomaa@peliturnarit.fi', '+3584634176571', '00880', 'Tulppatie', '7E 4'),
  ('T002', 'O001', 'Niina', 'Pousi', 'niina.pousi@peliturnarit.fi', '+3580403372373', '06100', 'Rantakatu', '5A 6'),
  ('T003', 'O002', 'Paul', 'Hinkel', 'paul.hinkel@globalbgass.com', '209-226-5969', '02184', 'Laurel Road', '4'),
  ('T004', 'O002', 'Susan', 'Burns', 'susan.burns@globalbgass.com', '209-235-4982', '92374', 'Post Street', '3A 5'),
  ('T005', 'O003', 'Elia', 'Schwerner', 'elia.schwerner@erdunfolge.de', '+4909087794512', '5020', 'Raschenbergstraße', '11'),
  ('T006', 'O004', 'Roza', 'Dmitrievna', 'roza.dmitrievna@sevnesti.ru', '+7(3435)820509', '454085', 'улица Грибоедова', '30'),
  ('T007', 'O004', 'Berezina', 'Yanovna', 'berezina.yanovna@sevnesti.ru', '+7(3513)796752', '456780', 'Советская улица', '40A 12'),
  ('T008', 'O004', 'Viktor', 'Vsevolotov', 'viktor.vsevolotov@sevnesti.ru', '+7(8552)712462', '454017', 'улица Румянцева', '31B 34'),
  ('T009', 'O009', 'Peter', 'Mikkelsen', 'peter.mikkelsen@agtespillere.dk', '+4541449509', '6400', 'Grundtvigsparken', '4C 1'),
  ('T010', 'O005', 'Fumihito', 'Kawagoe', 'fumihito.kawagoe@roiyarugema.ja', '+81749619914', '371-0022', '津久田停車場前橋線', '46'),
  ('T011', 'O010', 'Nikita', 'Söderberg', 'nikita.soderberg@forloradeviking.se', '+4609134963893', '15257', 'Fuxvägen 3', '3'),
  ('T012', 'O005', 'Toshikage', 'Ishigami', 'toshikage.ishigami@roiyarugema.ja', '+81846322201', '431-1209', 'イハラ美容室, 門前通り', NULL),
  ('T013', 'O006', 'Adrían', 'Guzmán', 'adrian.guzman@orgnivel.ar', '+541142048156', '8300LSB', 'Socompa', '355'),
  ('T014', 'O007', 'Lucas', 'Semmelweis', 'lucas.semmelweis@eurspielen.at', '+4306995884294', '5710', 'Dorfstraße', '5D 16'),
  ('T015', 'O008', 'Catarina', 'de Freitas', 'catarina.freitas@tabuleiro.br', '+55(62)73309001', '30285-110', 'Rua Desembargador Saraiva', '17'),
  ('T016', 'O009', 'Amanda', 'Danielsen', 'amanda.danielsen@agtespillere.dk', '+4553629301', '8270', 'Filippavej', '39'),
  ('T017', 'O004', 'Isabella', 'Samoylova', 'isabella.samoylova@sevnesti.ru', '+7(8552)882836', '433100', 'улица Маяковского', '14'),
  ('T018', 'O005', 'Yasumoto', 'Maihara', 'yasumoto.maihara@roiyarugema.ja', '+81628190292', '432-8058', '浜松市立可新図書館, 舞阪竜洋線', NULL),
  ('T019', 'O011', 'Paul', 'Allison', 'paul.allison@americanchallenger.com', '218-227-0680', '55118', 'Edith Drive', '293')
;

-- -----------------------------------------------------
-- Insert data for table CLUBROOM
-- -----------------------------------------------------

INSERT INTO CLUBROOM (id, name, postalcode, street, housenumber) VALUES
  ('LAUT', 'Lautakomero', '00510', 'Kajaaninkatu', '1'),
  ('HILL', 'Hillcavern Domain', '1060', 'Obere Windmühle', '5'),
  ('DRAG', 'Dragon\'s Lair', '112 20', 'Kungsholmstorg', '8'),
  ('STRA', 'Strategicon', '90045', 'Century Bulevard', '5711 W'),
  ('CONG', 'Congress-Centrum Nord Koelnmesse', '50679', 'Messeplatz', '1')
;

-- -----------------------------------------------------
-- Insert data for table GAME_EVENT
-- -----------------------------------------------------

INSERT INTO GAME_EVENT (id, clubroom_id, name, starttime, endtime, event_fee, extrainfo) VALUES
  (
    'E001',
    'LAUT',
    'DnD Rogue Challenge',
    '2019-11-23 14:00:00.000',
    '2019-11-24 06:00:00.000',
    10,
    'Come to see world\'s top teams challenging each other.'
  ),
  (
    'E002',
    'STRA',
    'Strategicon',
    '2020-02-14 09:00:00.000',
    '2020-02-17 22:00:00.000',
    200,
    'The tournament is one of the biggest and takes place in California, United States.'
  ),
  (
    'E003',
    NULL,
    'DnDSports',
    '2020-01-06 08:30:00.000',
    '2020-01-12 18:00:00.000',
    5,
    'Challenge top teams in this online gaming event and win your place!'
  ),
  (
    'E004',
    'CONG',
    'Gamescom',
    '2020-08-25 08:00:00.000',
    '2020-08-29 23:59:59.000',
    70,
    'Diverse german game tournament brings players together around the world!'
  )
;

-- -----------------------------------------------------
-- Insert data for table RESERVATION
-- -----------------------------------------------------

INSERT INTO RESERVATION (organizer_org_id, clubroom_id, time) VALUES
  ('O001', 'LAUT', '2019-11-16 12:44:23.000'),
  ('O007', 'CONG', NULL),
  ('O011', 'STRA', '2019-08-02 13:42:15.534')
;

-- -----------------------------------------------------
-- Insert data for table ARRANGEMENT
-- -----------------------------------------------------

INSERT INTO ARRANGEMENT (organizer_org_id, event_id) VALUES
  ('O001', 'E001'),
  ('O002', 'E002'),
  ('O007', 'E004'),
  ('O011', 'E003'),
  ('O008', 'E002')
;

-- -----------------------------------------------------
-- Data for table TEAM_STATUS
-- -----------------------------------------------------

INSERT INTO TEAM_STATUS (team_id, event_id, team_status, rank) VALUES
  ('J001', 'E001', 'ranked',   3),
  ('J008', 'E001', 'played',      NULL),
  ('J005', 'E004', 'registered', NULL),
  ('J006', 'E001', 'ranked',   1),
  ('J002', 'E002', 'registered', NULL),
  ('J003', 'E003', 'registered', NULL),
  ('J007', 'E004', 'registered', NULL)
;

-- -----------------------------------------------------
-- Data for table PLAYER_RANK
-- -----------------------------------------------------

INSERT INTO PLAYER_RANK (player_id, team_id, rank) VALUES
  ('P001', 'J001', 2),
  ('P023', 'J001', 1),
  ('P006', 'J003', 2),
  ('P007', 'J003', 1),
  ('P005', 'J002', 2),
  ('P022', 'J008', 2),
  ('P010', 'J004', 4),
  ('P018', 'J009', 2),
  ('P002', 'J001', 3),
  ('P003', 'J002', 1),
  ('P014', 'J007', 2),
  ('P020', 'J005', 2),
  ('P009', 'J004', 1),
  ('P008', 'J004', 2),
  ('P013', 'J006', 2),
  ('P012', 'J005', 1),
  ('P011', 'J004', 3),
  ('P015', 'J007', 1),
  ('P004', 'J002', 3),
  ('P019', 'J006', 1),
  ('P016', 'J008', 1),
  ('P017', 'J009', 1),
  ('P021', 'J005', 3)
;

-- -----------------------------------------------------
-- Data for table TEAM_RANK_GLOBAL
-- -----------------------------------------------------

INSERT INTO TEAM_RANK_GLOBAL (rank, team_id) VALUES
  (432, 'J001'),
  (257, 'J003'),
  (45,  'J005'),
  (786, 'J009'),
  (324, 'J006'),
  (127, 'J004'),
  (74,  'J002'),
  (675, 'J007'),
  (390, 'J008')
;

-- -----------------------------------------------------
-- Insert data for table BETTOR
-- -----------------------------------------------------

INSERT INTO BETTOR (id, firstname, lastname, email, phone, IBAN, SWIFT_bank, SWIFT_number, password) VALUES
  (
    'ForceWeaver',
    'Niko',
    'Tepponen',
    'forceweaver77@hotmail.com',
    '0445321770',
    'FI7176990982569721',
    NULL,
    NULL,
    'd9bb16f24a9d35a57b6dec1603e9d12780dce7116d160a743b6fee5cdcb4ed70c494b6b838b7b5bff286079f19f6295d27fef573883eae6e9ec1d604d79b4ec7'
  ),
  (
    'Katotoku',
    'Lian',
    'Yü',
    'katotokuyu@baidu.com',
    '13073390338',
    NULL,
    'GDBKCN22GZ1',
    '634863382282',
    '0caa4969caf0a65a89de430a1af8db3ce654c46415b63af5d7e959524e972d2de83b6a405cd60d9940c6a6d4cd760328e580e63a05b71d9312d3a6b2f2b297bf'
  ),
  (
    'Tadotaka',
    'Gang',
    'Ch\'ien',
    'tadotakagang@baidu.com',
    '+8613013867507',
    NULL,
    'CRESCNSH',
    '056656945387',
    'f8af7b436482adf71a00de95be18c944775b0cb9734332ccd5f323b3d6e6f92da67941c9469a478f4af17b6344078dfdfc2992f7a62b0b0ba93762cdf83d4ffc'
  ),
  (
    'Katoteshi', 
    'Cong', 'Hsiao', 
    'katoteshicong@yahoo.com', 
    '+13063889088', 
    NULL, 'PCBCCNBJAHX', 
    '687790432934',
    'e4507172adcf0608b307ab4d27341754cbcd54d03c06ad8848903ef88a5a5fc60df11fa5e6ab4b8d9b0e25b7fd16a3cce9e4e432137b653d432169f0ed16acde'
  ),
  (
    'Sandgrinder', 
    'Evgenija', 
    'Balentin', 
    'sandgrinder343@gmail.com', 
    '+48882484598', 
    NULL, 
    'EBOSPLPW005', 
    '6267746983',
    '8c62deedfe2a5ce2136b4afe9925e04453f44e3ead02b8ac931831542df95e2cc2d7da45584c59a6eee179c87ac66a37a1669c17688ba2d00dea437f932b8b21'
  ),
  (
    'Lothran', 
    'Heiða', 
    'Þorgrímsdóttir', 
    'lothranwiz@outlook.com', 
    '+35465553958', 
    NULL, 
    'SISLISRE', 
    '04911539522202',
    '11325a7fdd174376157a55557efa16eb9a6a50a95fa0f32134c3be1722dbfcbb0555d2b31215eaac3b2dbabed9897ee6b320b7ca53d52450cdbc363eea64f267'
  ),
  (
    'Isengrin', 
    'Lóa', 
    'Hervinsson', 
    'isegrin82@hotmail.com', 
    '+35465558357', 
    NULL, 
    'DABADKKKBAL', 
    '4681967034',
    '2486f5f8ac1bf7e2d85942f57748d9a8c1cdfcb090f0c42ec096daa0df4b961029e2bb72a419014eaf506ac0176de728e864fc5be4c98c221b9c3ba78f68c6c1'
  ),
  (
    'waterheaver', 
    'Ila', 
    'Fouquet', 
    'waterheaver12@hotmail.com', 
    NULL, 
    NULL, 
    'ALLZFRPP', 
    '7369781413',
    '9c2a933c3543682a6497fa3ed4fdb128b1582b57644cd56a64d46769c38149ed6ddcfe8ce2b72fa0c4463901f80d127a3fe1498bfc72d30f674654a15509a83f'
  ),
  (
    'Bugaloo', 
    'Casper', 
    'Berge', 
    'bugaloozoo@gmail.com', 
    NULL, 
    NULL, 
    'BOFAIE3XSBL', 
    '7746897535',
    'dd61748a588b01a76fddea3af6d50e9a92d4d4dcb157eaa12063c14962af38c2061cdc30cfaac973ea2593b063f3a29b9fe4030d52f8e7a1d82ccc86df93dae8'
  ),
  (
    'Undertaker', 
    'Felicia', 
    'Thoresen', 
    'undertakergin6@yahoo.com', 
    NULL, 
    NULL, 
    'DABANO22', 
    '4310141078',
    '468ff41e74846c00473f90893b499cf63831d967b63daa4c78aaa23dcacc9ad75309608d2540685af9299ed3a8116521454fb27d6b80d5a41feae1380c24e3aa'
  ),
  (
    'Jackhammer', 
    'Felix', 
    'Grunewald', 
    'jackthehammer@outlook.com', 
    '+4906432579977', 
    NULL, 
    'VPCSSESSCLP', 
    '29352045380419',
    'abf8800c00f692150ae944dbc4e7d328b77cd5a42fb307a02045d09944285657b5fe77f06a9ef9f0e762affb2e59f85ab597e5c290e4788ce91b3ec73c3600c9'
  ),
  (
    'eranen', 
    'Kristian', 
    'Eisenberg', 
    'eranen_berg@hotmail.com', 
    NULL, 
    NULL, 
    'DABASESX', 
    '0171699755',
    '0541bbccef9268dfbb11fccfb26e2a83205233b677dd8516ef020466cd46581de5947fb9b686d03bd4e71b255cc09e90b5832ccc591cf2ccafe8e9b525051d69'
  ),
  (
    'Rutida', 
    'Niklas', 
    'Friedmann', 
    'rutidarouting@gmail.com', 
    NULL, 
    NULL, 
    'DKNBDKK3', 
    '266423564818',
    '98751076c8b89f2c667b2a15abe6eb7137b666cd676a79a3cc137d594dc4cdd8e934711a8a66afe78ec7df58aac40d8eb4e2932b15952ff7d77676370e68a74c'
  )
;

-- -----------------------------------------------------
-- Insert data for table BETTING
-- -----------------------------------------------------

INSERT INTO BETTING (bettor_id, event_id, team_id, team_rank_guess, multiplier, initmoney, betstatus) VALUES
  ('Isengrin',    'E004', 'J007', 2, 2.4, 112.50, 'queued for approval'),
  ('Katoteshi',   'E002', 'J002', 1, 1.55, 14.00, 'queued for approval'),
  ('Rutida',      'E003', 'J003', 3, 4.5, 34.20,  'queued for approval'),
  ('ForceWeaver', 'E001', 'J001', 1, 7, 90,    'no win'),
  ('Sandgrinder', 'E001', 'J001', 2, 5.4, 140, 'no win')
;
