/*
  MySQL SQL query script for Tournament database
  Designed for MariaDB RDBMS

  Author:
    Pekka Helenius <fincer89 [at] hotmail [dot] com>
    2019
*/

-- -----------------------------------------------------
-- Assumes that database 'tournament_db' exists
USE tournament_db;

-- -----------------------------------------------------
/*
  ASSIGNMENT 14

Logged in russian player Myron Ponomarev has moved away from his old home region. Therefore, he wants to update his contact information.

The tournament platform has a web-based front-end which connects indirectly to the back-end servers. The player can change his information only via this web interface.

The player types the following information as input:
  - postal code:     141300
  - postal district: Северный
  - street: улица    Чапаева
  - house number:    22

The country code does not change and stays locked in selection "Russia".

After clicking "Accept" and checking permissions and validity of the updated information, the database server performs operations according to program logic.

Do these operations manually to the tournament database.
*/

-- -----------------------------------------------------

/* Adding new city information for Russia */
INSERT INTO CITY (postalcode, country_id, name) VALUES
  ('141300', 'RU', 'Северный');

UPDATE PLAYER
  SET
    postalcode  = '141300',
    street      = 'улица Чапаева',
    housenumber = '22'

  WHERE
    id        = 'P010' AND
    firstname = 'Myron' AND
    lastname  = 'Ponomarev'
;

-- -----------------------------------------------------
/*
  ASSIGNMENT 15

Already registered game tournament DnDSports is wanted to be organized just under christmas 2019. Due to this sudden demand, the event period is shifted 24 days backwards. To gain more value for the event and to reduce criticism the event time is also extended by 2 days.

Due to christmas season the additional information is updated. The new information reads:

'Challenge top teams in this online gaming event and win your place! This event has also christmas magic for everyone!'

Due to extended duration and additional christmas value participation fee is increased by 10 euros compared to the current fee.

Apply these changes to the tournament database.

*/
-- -----------------------------------------------------

UPDATE GAME_EVENT
  SET
    /* MySQL */
    starttime   = DATE_ADD(starttime, INTERVAL '-12' DAY),
    endtime = DATE_ADD(endtime, INTERVAL '-10' DAY),
    /* SQL Server */
    -- starttime   = DATEADD(DAY, -12, starttime),
    -- endtime = DATEADD(DAY, -10, endtime)
    event_fee = (event_fee + 10),
    extrainfo = CONCAT(extrainfo, ' This event has also christmas magic for everyone!')

  WHERE
    id = 'E003' AND
    name = 'DnDSports'
;

-- -----------------------------------------------------
/*
  ASSIGNMENT 16

Finnish team Rollihaukat played in DnD Rogue Challenge tournament. Their initial ranking was set to 3. However, after the event it was noticed that there was happened a mistake during result calculation. After correcting the results, it was found out that Rollihaukat actually won the event. There were other teams in the event, as well. One of them, swedish Vita Frost Bringararna, was ranked to the first place before the mistake was noticed. Instead, the swedish team took the second place.

There were possibility to bet on favorite teams. One bettor, known as ForceWeaver, bet on Rollihaukat to win the event. Due to mistake, the bettor was informed that he/she was lost which was not actually the case, as it was discovered later.

The game organizer sent apologies for all participants and the error was corrected very quickly. The swedish team was also informed about changes in the ranking order. The bettor got his/her prize money and teams their honor, respectfully.

Other human errors were discovered, as well: information about russian team Red Hats was totally missing. The russian team took the third place after error corrections were made. Brazilian team Comedores de Caveira aborted during the event and dropped from ranking.

Fix the data errors described above.
*/
-- -----------------------------------------------------

-- 1) Update Rollihaukat ranking to value 1 in DnD Rogue Challenge event

UPDATE TEAM_STATUS
  SET rank = 1
WHERE team_id = 'J001' AND event_id = 'E001'
;

-- 2) Update Vita Frost Bringararna ranking to value 2 in DnD Rogue Challenge event

UPDATE TEAM_STATUS
  SET rank = 2
WHERE team_id = 'J006' AND event_id = 'E001'
;

-- 3) Add ranking information of team Red Hats in DnD Rogue Challenge event
-- Ranking value is 3.

INSERT INTO TEAM_STATUS (team_id, event_id, team_status, rank) VALUES
 ('J004', 'E001', 'ranked', 3)
;

-- 4) Change betstatus of ForceWeaver to value 'won' in the DnD Rogue Challenge event

UPDATE BETTING
  SET betstatus = 'won'
WHERE
  bettor_id = 'ForceWeaver' AND
  event_id  = 'E001' AND
  team_id   = 'J001'
;

-- -----------------------------------------------------
/*
  ASSIGNMENT 17

Employee Adrían Guzmán who works for Argentinean organizer Organización de mejora de nivel gets married. The happy event means his surname changes and he moves away from his current home town. Therefore, his postal code and street address change, too.

Due to these radical changes in his life, he gets employed and works for brazilian tournament organization Associação Sul-Americana de Jogos de Tabuleiro.

After all, he updates his contact information. The new information is:
  - Name:                Adrían Fernanda Quezada
  - Contact information: Delfín 38, Toay, 6303, Argentina

This information is being updated in the tournament database. Apply the changes manually.
*/
-- -----------------------------------------------------

INSERT INTO CITY (postalcode, country_id, name) VALUES
  ('6303', 'AR', 'Toay')
;

UPDATE ORG_EMPLOYEE
  SET
    organizer_org_id = 'O008',
    lastname         = 'Fernanda Quezada',
    postalcode       = '6303',
    street           = 'Delfín',
    housenumber      = '38'
  WHERE id = 'T013'
;
