/*
  MySQL SQL query script for Tournament database
  Designed for MariaDB RDBMS

  Author:
    Pekka Helenius <fincer89 [at] hotmail [dot] com>
    2019
*/

-- -----------------------------------------------------
-- Assumes that database 'tournament_db' exists
USE tournament_db;

-- -----------------------------------------------------
/*
  ASSIGNMENT 18

Iranian team, known internationally as BattleBrothers, has been temporarily banned from tournament events due to policy violation in an event held in another tournament platform.

Our tournament database has an unexpected issue: we do not have any information regarding to team license or whether teams are allowed to play in events. This was not considered during database development phase.

Because the ban is given by the top global tournament organization Boardgame Players Association and the company does not want to run out from business due to a silly mistake, the company board orders database administators to make proper changes to current database structure immediately. The license status must be placed in a way or another. During the ban period, no event fees are being allowed from the banned team.

The database administrators try to adapt to the changed situation and work in pressure. They need to make sure that database integrity will not be broken in any case which is why full database backup is taken before necessary changes.

After the database structure changes and successful tests one of the administrators inform the company board that necessary updates have been made. Additionally, the information was delivered to programming department in the company.

The corporate communications officer informs the global tournament organization that the situation is under control and the company has made required adaptions to the tournament platform.

During the database structure update the administators decided to make further improvements and add gaming license status information for each team in the database.

After the procedures the database diagrams & formulas were updated in addition to database integrity and normalization checks.

Apply all database changes described above with proper SQL queries (excluding normalization, diagrams and formulas).
*/
-- -----------------------------------------------------

-- 1) Remove BattleBrothers from TEAM_RANK_GLOBAL table

DELETE FROM TEAM_RANK_GLOBAL
  WHERE team_id = 'J009'
;

-- 2) Add new column 'game_license' into TEAM table
-- The column data type is NVARCHAR(20) NOT NULL
-- Accepted values are: 'active', 'archived' and 'banned'

-- Add the new column and a default value
ALTER TABLE TEAM
  ADD game_license NVARCHAR(20) NOT NULL DEFAULT('active') AFTER name
;

-- MariaDB 10.2 implements CHECK constraints
-- https://mariadb.com/kb/en/library/changes-improvements-in-mariadb-102/
-- Determine your version with query: SELECT @@version

/* MySQL */
ALTER TABLE TEAM
  ADD CHECK(
    game_license = 'active' OR
    game_license = 'archived' OR
    game_license = 'banned'
);

/* SQL Server */
/*
ALTER TABLE TEAM
  ALTER COLUMN game_license WITH CHECK(
    game_license = 'active' OR
    game_license = 'archived' OR
    game_license = 'banned'
);
*/

UPDATE TEAM
  SET game_license = 'banned' WHERE id = 'J009';

-- -----------------------------------------------------
/*
  ASSIGNMENT 19

The database company board decided that to improve the use experience and obtain more valuable data, bettors should be able to add their personal contact information to the tournament platform via web interface. The order caused many kind of operations in programming and database departments. Database administrators were tasked to add support and change database structure so that web developers could implement changes to web front-end.

The new information should be determined before bettor's password information (password column must be the last one).

Apply required changes to the tournament database.
*/
-- -----------------------------------------------------

ALTER TABLE BETTOR
  ADD COLUMN postalcode  VARCHAR(10)  NULL AFTER phone,
  ADD COLUMN street      NVARCHAR(80) NULL AFTER postalcode,
  ADD COLUMN housenumber NVARCHAR(7)  NULL AFTER street
;

/* Removal with the following query

ALTER TABLE BETTOR
  DROP COLUMN housenumber,
  DROP COLUMN street,
  DROP COLUMN postalcode
;
*/
    
-- -----------------------------------------------------
/*
  ASSIGNMENT 20

During brain storming meetings it was noted that the current database does not support three-letter country codes. The company board wants support for three-letter country codes.

During the task, database administrators understood that as further improvement, it would be handy to have phone country prefix numbers directly among the other country data. The administrators implemented this extra feature although it was not utilized due to missing web application support.

Apply the reservation for new three-letter country codes. Add new country codes for each country in the database. Implement support for country-speficic phone number suffixes. Add new number suffixes.

What kind of difficult issues these changes can introduce to the database structure?

The database administrators used the following website as their information source for the new data:
https://www.worldatlas.com/aatlas/ctycodes.htm
*/
-- -----------------------------------------------------

/*
  Adding condition NOT NULL does not work
  Phone numbers can't be unique, check UPDATE values below
*/
ALTER TABLE COUNTRY
  ADD COLUMN id_a3        CHAR(3)    UNIQUE AFTER id,
  ADD COLUMN dialing_code VARCHAR(5) AFTER id_a3
;

UPDATE COUNTRY SET id_a3 = 'FIN', dialing_code = '358' WHERE id = 'FI';
UPDATE COUNTRY SET id_a3 = 'NOR', dialing_code = '47'  WHERE id = 'NO';
UPDATE COUNTRY SET id_a3 = 'USA', dialing_code = '1'   WHERE id = 'US';
UPDATE COUNTRY SET id_a3 = 'DEU', dialing_code = '49'  WHERE id = 'DE';
UPDATE COUNTRY SET id_a3 = 'RUS', dialing_code = '7'   WHERE id = 'RU';
UPDATE COUNTRY SET id_a3 = 'EST', dialing_code = '372' WHERE id = 'EE';
UPDATE COUNTRY SET id_a3 = 'JPN', dialing_code = '81'  WHERE id = 'JP';
UPDATE COUNTRY SET id_a3 = 'ARG', dialing_code = '54'  WHERE id = 'AR';
UPDATE COUNTRY SET id_a3 = 'ISL', dialing_code = '354' WHERE id = 'IS';
UPDATE COUNTRY SET id_a3 = 'AUT', dialing_code = '43'  WHERE id = 'AT';
UPDATE COUNTRY SET id_a3 = 'BRA', dialing_code = '55'  WHERE id = 'BR';
UPDATE COUNTRY SET id_a3 = 'DNK', dialing_code = '45'  WHERE id = 'DK';
UPDATE COUNTRY SET id_a3 = 'SWE', dialing_code = '46'  WHERE id = 'SE';
UPDATE COUNTRY SET id_a3 = 'IRN', dialing_code = '98'  WHERE id = 'IR';
UPDATE COUNTRY SET id_a3 = 'MLT', dialing_code = '356' WHERE id = 'MT';
UPDATE COUNTRY SET id_a3 = 'PRI', dialing_code = '1'   WHERE id = 'PR';
UPDATE COUNTRY SET id_a3 = 'SVN', dialing_code = '386' WHERE id = 'SI';
UPDATE COUNTRY SET id_a3 = 'VNM', dialing_code = '84'  WHERE id = 'VN';

INSERT INTO COUNTRY (id, id_a3, dialing_code, name) VALUES
  ('FR', 'FRA', '33', 'France') ON DUPLICATE KEY
  UPDATE id_a3 = 'FRA', dialing_code = '33'
;

INSERT INTO COUNTRY (id, id_a3, dialing_code, name) VALUES
  ('AU', 'AUS', '61', 'Australia') ON DUPLICATE KEY
  UPDATE id_a3 = 'AUS', dialing_code = '61'
;

INSERT INTO COUNTRY (id, id_a3, dialing_code, name) VALUES
  ('NZ', 'NZL', '64', 'New Zealand') ON DUPLICATE KEY
  UPDATE id_a3 = 'NZL', dialing_code = '64'
;

/*
  Change to NOT NULL after empty values have been filled.
  NOTE! This operation can cause issues so not all rows are filled
  beforehand.
*/
/* SQL Server */
-- ALTER TABLE COUNTRY
--   ALTER COLUMN id_a3        CHAR(3)    NOT NULL,
--   ALTER COLUMN dialing_code VARCHAR(5) NOT NULL;

/* MySQL */
ALTER TABLE COUNTRY
  MODIFY id_a3        CHAR(3)    NOT NULL,
  MODIFY dialing_code VARCHAR(5) NOT NULL
;

-- What kind of difficult issues these changes can introduce to the database structure?

/*
Answer:

Additional columns can cause issues in country code usage
since, after updates, two alternative country code formats
exist. The current primary key COUNTRY.id does not really
determine the country code format (2-letter or 3-letter).
Better name for this column could be 'id_a2' but this change
could break reference key structure in CITY table if
necessary changes will not be made.
The additional country code adds complexity for potential
references: which country code format should reference keys
actually refer to?

*/
