/*
  MySQL SQL query script for Tournament database
  Designed for MariaDB RDBMS

  Author:
    Pekka Helenius <fincer89 [at] hotmail [dot] com>
    2019
    
  Delete specific rows from selected and pre-existing
  tables in the selected database.
  Be careful not to break relations & integrity of
  the database (primary & foreign key relations)

*/

-- -----------------------------------------------------
-- Assumes that database 'tournament_db' exists
USE tournament_db;

-- -----------------------------------------------------
/*
  ASSIGNMENT 21

Tournament event Gamescom 2020 is cancelled. Privileged database administrator must delete the event from the database. Possible reasons for the cancellation are, for instance:
  - event organizer bankrupts
  - event does not get enough attraction and event organizer cancels the event

Since the event has received participation fees and several other profits, they must be refunded using various APIs.
*/
-- -----------------------------------------------------

-- 1) Delete event reservation
DELETE RESERVATION FROM RESERVATION, CLUBROOM
  JOIN GAME_EVENT P
    ON P.clubroom_id = CLUBROOM.id
  WHERE
    RESERVATION.clubroom_id = P.clubroom_id AND
    P.id = 'E004'
;

-- 2) Delete event arrangement information
DELETE ARRANGEMENT FROM ARRANGEMENT
  JOIN GAME_EVENT P
    ON P.id = ARRANGEMENT.event_id
  WHERE
    P.id = 'E004'
;

-- 3) Delete team status information from the event
DELETE TEAM_STATUS FROM TEAM_STATUS
  JOIN GAME_EVENT P
    ON P.id = TEAM_STATUS.event_id
  WHERE
    P.id = 'E004'
;

-- 4) Delete event betting information
DELETE BETTING FROM BETTING
  JOIN GAME_EVENT P
    ON P.id = BETTING.event_id
  WHERE
    P.id = 'E004'
;

-- 5) Delete the event
DELETE FROM GAME_EVENT
  WHERE id = 'E004';

/*
  Other, more user-friendlier way to show information
  regarding to a cancelled event would be better
  utilization of the existing web interface.
  The interface could have event status information
  'cancelled'. In the current database, table GAME_EVENT
  could have a suitable attribute [status] for this information.
*/
  
-- -----------------------------------------------------
/*
  ASSIGNMENT 22

As a result of the ban, iranian team BattleBrothers is deleted from the tournament database. The team and related data is simply deleted. Optional reasons for permanent deletion could be:
  - team has not been active for a long time
  - team breaks up or ceases to exist

Before the actual deletion existing team data should be archived via suitable APIs and using another archive database. The simple programming logic could be: WHEN team data is archived THEN delete the data from the tournament database. Archived data may help if any further confict will arise later on.
*/
-- -----------------------------------------------------

-- Team data is linked to multiple tables in the tournament database. Thus, the deletion is progressive, as shown below. 

USE tournament_db;

-- 1) Delete team-specific player ranking information
DELETE PLAYER_RANK FROM PLAYER_RANK
  JOIN TEAM J
    ON PLAYER_RANK.team_id = J.id
  WHERE
    J.id = 'J009'
;

-- 2) Delete team players
DELETE PLAYER FROM PLAYER
  JOIN TEAM J
    ON PLAYER.team_id = J.id
  WHERE
    J.id = 'J009'
;

-- 3) Delete team event status information
DELETE TEAM_STATUS FROM TEAM_STATUS
  JOIN TEAM J
    ON TEAM_STATUS.team_id = J.id
  WHERE
    J.id = 'J009'
;

-- 4) Delete team global ranking information
DELETE TEAM_RANK_GLOBAL FROM TEAM_RANK_GLOBAL
  JOIN TEAM J
    ON TEAM_RANK_GLOBAL.team_id = J.id
  WHERE
    J.id = 'J009'
;

-- 5) Delete team-related betting information
DELETE BETTING FROM BETTING
  JOIN TEAM J
    ON BETTING.team_id = J.id
  WHERE
    J.id = 'J009'
;

-- 6) Delete the team from the database
DELETE FROM TEAM WHERE id = 'J009';

-- -----------------------------------------------------
/*
  ASSIGNMENT 23

Russian organizer северные медведи bankrupts. Once the news reach the tournament company, database administrators take an action to delete information related to the organizer. The organizer and all related data is deleted.

Other reasons for deleting an organizer could be a fusion of multiple organizers.

NOTE:

Before the actual data removal it would be encouraged to back it up and clone, for instance, to another archival database.
Basically, the proceduce could be as follows: WHEN organization information is archived, THEN delete the data from this database. Archived data could help in indisputability of the data validity if it's ever needed afterwards.

*/
-- -----------------------------------------------------

-- Organizer data is linked to multiple tables in the tournament database. Thus, the deletion is progressive, as shown below.

-- 1) Delete organizer employee information
DELETE ORG_EMPLOYEE FROM ORG_EMPLOYEE
  JOIN ORGANIZER_ORG J
    ON ORG_EMPLOYEE.organizer_org_id = J.id
  WHERE
    J.id = 'O004'
;

-- 2) Delete reservations by the organizer
DELETE RESERVATION FROM RESERVATION
  JOIN ORGANIZER_ORG J
    ON RESERVATION.organizer_org_id = J.id
  WHERE
    J.id = 'O004'
;

-- 3) Delete tournament arrangement information
-- by the organizer
DELETE ARRANGEMENT FROM ARRANGEMENT
  JOIN ORGANIZER_ORG J
    ON ARRANGEMENT.organizer_org_id = J.id
  WHERE
    J.id = 'O004'
;

-- 4) Delete the organizer from the database
DELETE FROM ORGANIZER_ORG WHERE id = 'O004';

-- -----------------------------------------------------
/*
  ASSIGNMENT 24

Bettor nicknamed as Katoteshi has cheated and his/her actions have led to a criminal investigation due to not returned win prizes he/she has received. Due to cheating all logged actions and old/new account information is backed up which helps in the investigation. Once the criminal investigation is started, the bettor is deleted from the tournament database.

In general, other reasons for account deletion could be
  - supplying false information
  - general cheating
  - very long inactivity time

Tournament database administrators get a task to delete the bettor from the database.
*/
-- -----------------------------------------------------

-- 1) Delete betting information related to the bettor
DELETE FROM BETTING WHERE bettor_id = 'Katoteshi';

-- 2) Delete the bettor
DELETE FROM BETTOR WHERE id = 'Katoteshi';

-- -----------------------------------------------------
/*
  ASSIGNMENT 25

Database company owning the tournament database has changed its terms of use for the tournament application platform. Major changes for players include requirement of having personal contact information connected to new and existing accounts. To be specific, the required information is:

  - phone number
  - postal code
  - street
  - house number

Earlier this information was optional and only email information was required.

A database administrator sends a group email to notify players about the changed terms of use. The administrator wants to send the email only for players lacking the required contact information to avoid spamming messages unnecessarily. The email message has a clearly stated deadline after which the database company reserves rights to delete player information from the tournament database unless the new terms of use conditions have been met.

The database administrators obtain names of the players missing the required information with SQL SELECT queries. After deadline, the administrator executes DELETE queries.

The following players have not added required contact information in required time:

  - Lạc Trọng Phu
  - Hàn Hữu Nghi
  - Lê Đình Hưng
  - Minan Ikegami

Before delete operations the administrator archives related player data. An email is sent to the deleted players. These operations are excluded from this task.

Apply the delete operations described above.
*/
-- -----------------------------------------------------

-- 1) Delete player's team-specific rank information

DELETE PLAYER_RANK FROM PLAYER_RANK
  JOIN PLAYER P
    ON PLAYER_RANK.player_id = P.id
  WHERE
    (P.id = 'P012' AND P.firstname = 'Lạc'   AND P.lastname = 'Trọng Phu');

DELETE PLAYER_RANK FROM PLAYER_RANK
  JOIN PLAYER P
    ON PLAYER_RANK.player_id = P.id
  WHERE
    (P.id = 'P020' AND P.firstname = 'Hàn'   AND P.lastname = 'Hữu Nghi');

DELETE PLAYER_RANK FROM PLAYER_RANK
  JOIN PLAYER P
    ON PLAYER_RANK.player_id = P.id
  WHERE
    (P.id = 'P021' AND P.firstname = 'Lê'    AND P.lastname = 'Đình Hưng');

DELETE PLAYER_RANK FROM PLAYER_RANK
  JOIN PLAYER P
    ON PLAYER_RANK.player_id = P.id
  WHERE
    (P.id = 'P004' AND P.firstname = 'Minan' AND P.lastname = 'Ikegami');

-- 2) Delete player information
DELETE FROM PLAYER WHERE
    (id = 'P012' AND firstname = 'Lạc'   AND lastname = 'Trọng Phu') OR
    (id = 'P020' AND firstname = 'Hàn'   AND lastname = 'Hữu Nghi')  OR
    (id = 'P021' AND firstname = 'Lê'    AND lastname = 'Đình Hưng') OR
    (id = 'P004' AND firstname = 'Minan' AND lastname = 'Ikegami')
;


-- 3) NOTE! Team J005 remains without players. Because the team could have
-- additional members in the future and it has valid ranking information,
-- we shall not delete the team itself.
-- However, after very long inactivity period the team deletion could be possible.

-- -----------------------------------------------------
/*
  ASSIGNMENT 26

Tournament database administator want to purge unused, orphaned city information from the tournament database. To avoid unnecessary data bloat the cleaning operation is well justified.

Delete unused cities and towns from the tournament database.
*/
-- -----------------------------------------------------

/*
  Bypass safe update check. Otherwise MySQL server returns
  an error regarding to failed delete operations.
  NOTE! This query has been tested and validated to be safe
  for database integrity and structure.
*/
SET SQL_SAFE_UPDATES = 0;

DELETE FROM CITY
  WHERE postalcode IN (
    SELECT postalcode FROM (
      SELECT CITY.* FROM (
      
        SELECT DISTINCT 
         postalcode AS postalcode_used
	    FROM ORG_EMPLOYEE
        
        UNION
        
        SELECT DISTINCT 
          postalcode AS postalcode_used
	    FROM ORGANIZER_ORG
        
        UNION
        
        SELECT DISTINCT 
          postalcode AS postalcode_used
	    FROM PLAYER
        
        UNION
        
        SELECT DISTINCT 
          postalcode AS postalcode_used
	    FROM TEAM
        
        UNION
      
        SELECT DISTINCT 
          postalcode AS postalcode_used
        FROM CLUBROOM
      
      ) USED_ZIPCODES

      RIGHT JOIN CITY ON
        USED_ZIPCODES.postalcode_used = CITY.postalcode

      WHERE USED_ZIPCODES.postalcode_used IS NULL

    ) UNUSED_ZIPCODES
  )
;

-- -----------------------------------------------------
/*
  ASSIGNMENT 27

Tournament database administator want to purge unused, orphaned country information from the tournament database. To avoid unnecessary data bloat the cleaning operation is well justified.

Delete unused countries and country codes from the tournament database.
*/
-- -----------------------------------------------------

/*
  Bypass safe update check. Otherwise MySQL server returns
  an error regarding to failed delete operations.
  NOTE! This query has been tested and validated to be safe
  for database integrity and structure.
*/
SET SQL_SAFE_UPDATES = 0;

DELETE FROM COUNTRY
  WHERE id IN (
    SELECT id FROM (
      SELECT COUNTRY.* FROM COUNTRY
        LEFT JOIN CITY ON
          COUNTRY.id = CITY.country_id
        WHERE CITY.name IS NULL
    ) UNUSED_COUNTRIES
  )
;
